@@ -7,22 +7,17 @@ Rationale:
 The ``use_pyscaffold`` keyword is unknown to setuptools' setup(...) command,
 therefore the ``entry_points`` are checked for a function to handle this
 keyword which is ``pyscaffold_keyword`` below. This is where we hook into
-setuptools and apply the magic of setuptools_scm and pbr.
+setuptools and apply the magic of setuptools_scm as well as other commands..
 """
-
 from __future__ import division, print_function, absolute_import
 
-import os
+import sys
 from distutils.cmd import Command
 
-from pyscaffold.contrib import pbr_read_setup_cfg, scm_get_version
+from pyscaffold.contrib import ptr
+from pyscaffold.contrib.setuptools_scm import get_version, discover
 from pyscaffold.utils import check_setuptools_version
 from pyscaffold.repo import get_git_root
-from pyscaffold.pytest_runner import PyTest
-
-__author__ = "Florian Wilhelm"
-__copyright__ = "Blue Yonder"
-__license__ = "new BSD"
 
 
 def version2str(version):
@@ -58,19 +53,9 @@ def local_version2str(version):
         return ''
     else:
         if version.dirty:
-            return version.format_with('+n{node}.dirty')
+            return version.format_with('+{node}.dirty')
         else:
-            return version.format_with('+n{node}')
-
-
-def deactivate_pbr_authors_changelog():
-    """Deactivate automatic generation of AUTHORS and ChangeLog file
-
-    This is an automatism of pbr and we rather keep track of our own
-    AUTHORS.rst and CHANGES.rst files.
-    """
-    os.environ['SKIP_GENERATE_AUTHORS'] = "1"
-    os.environ['SKIP_WRITE_GIT_CHANGELOG'] = "1"
+            return version.format_with('+{node}')
 
 
 def build_cmd_docs():
@@ -94,6 +79,17 @@ def build_cmd_docs():
         return BuildDoc
 
 
+class PyTest(ptr.PyTest):
+    def run_tests(self):
+        try:
+            import pytest  # noqa
+        except ImportError:
+            raise RuntimeError("PyTest is not installed, run: "
+                               "pip install pytest pytest-cov")
+        super(PyTest, self).run_tests()
+        sys.exit(self.result_code)
+
+
 def pyscaffold_keyword(dist, keyword, value):
     """Handles the `use_pyscaffold` keyword of the setup(...) command
 
@@ -109,16 +105,11 @@ def pyscaffold_keyword(dist, keyword, value):
         value.setdefault('root', get_git_root(default='.'))
         value.setdefault('version_scheme', version2str)
         value.setdefault('local_scheme', local_version2str)
-        if os.path.exists('PKG-INFO'):
+        matching_fallbacks = discover.iter_matching_entrypoints(
+            '.', 'setuptools_scm.parse_scm_fallback')
+        if any(matching_fallbacks):
             value.pop('root', None)
-        command_options = dist.command_options.copy()
-        cmdclass = dist.cmdclass.copy()
-        deactivate_pbr_authors_changelog()
-        pbr_read_setup_cfg(dist, keyword, True)
-        dist.metadata.version = scm_get_version(**value)
-        # Adding old command classes and options since pbr seems to drop these
+        dist.metadata.version = get_version(**value)
         dist.cmdclass['doctest'] = build_cmd_docs()
         dist.command_options['doctest'] = {'builder': ('setup.py', 'doctest')}
         dist.cmdclass['test'] = PyTest
-        dist.cmdclass.update(cmdclass)
-        dist.cmdclass.update(command_options)
